==> openflowplugin-extension-nicira-0.5.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/OfpactActions.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * Actions to be performed with conntrack.
 *
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping ofpact-actions {
 *     choice ofpact-actions {
 *         case nx-action-nat-case {
 *             container nx-action-nat {
 *                 leaf flags {
 *                     type uint16;
 *                 }
 *                 leaf range_present {
 *                     type uint16;
 *                 }
 *                 leaf ip-address-min {
 *                     type ip-address;
 *                 }
 *                 leaf ip-address-max {
 *                     type ip-address;
 *                 }
 *                 leaf port-min {
 *                     type uint16;
 *                 }
 *                 leaf port-max {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions</i>
 *
 */
public interface OfpactActions
    extends
    DataObject
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "ofpact-actions").intern();

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.OfpactActions</code> <code>ofpactActions</code>, or <code>null</code> if not present
     */
    org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.OfpactActions getOfpactActions();

}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/OfpactActions.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * Actions to be performed with conntrack.
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping ofpact-actions {
 *     choice ofpact-actions {
 *         case nx-action-ct-mark-case {
 *             container nx-action-ct-mark {
 *                 leaf ct-mark {
 *                     type uint32;
 *                 }
 *             }
 *         }
 *         case nx-action-nat-case {
 *             container nx-action-nat {
 *                 leaf flags {
 *                     type uint16;
 *                 }
 *                 leaf range_present {
 *                     type uint16;
 *                 }
 *                 leaf ip-address-min {
 *                     type ip-address;
 *                 }
 *                 leaf ip-address-max {
 *                     type ip-address;
 *                 }
 *                 leaf port-min {
 *                     type uint16;
 *                 }
 *                 leaf port-max {
 *                     type uint16;
 *                 }
 *             }
 *         }
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/ofpact-actions</i>
 *
 */
public interface OfpactActions
    extends
    DataObject
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "ofpact-actions").intern();

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.OfpactActions</code> <code>ofpactActions</code>, or <code>null</code> if not present
     */
    org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.ofpact.actions.OfpactActions getOfpactActions();

}
